Index: src/compiler/ast-graph-builder.h |
diff --git a/src/compiler/ast-graph-builder.h b/src/compiler/ast-graph-builder.h |
index 45f7451652da34fb40d3d18c6cc49d860ecc832d..4e3a9e310eafe1d2b5260cba835b862f9a002c55 100644 |
--- a/src/compiler/ast-graph-builder.h |
+++ b/src/compiler/ast-graph-builder.h |
@@ -245,8 +245,9 @@ class AstGraphBuilder : public AstVisitor { |
// Builder to create a receiver check for sloppy mode. |
Node* BuildPatchReceiverToGlobalProxy(Node* receiver); |
- // Builders to create local function and block contexts. |
- Node* BuildLocalFunctionContext(Node* context, Node* closure); |
+ // Builders to create local function, script and block contexts. |
+ Node* BuildLocalFunctionContext(Node* context); |
+ Node* BuildLocalScriptContext(Scope* scope); |
Node* BuildLocalBlockContext(Scope* scope); |
// Builder to create an arguments object if it is used. |